@@ -35,8 +35,8 @@ import com.google.common.collect.ImmutableMap;
 
 public class EdgeAPI extends GraphAPI {
 
-    public EdgeAPI(RestClient client, String graph) {
-        super(client, graph);
+    public EdgeAPI(RestClient client, String graphSpace, String graph) {
+        super(client, graphSpace, graph);
     }
 
     @Override
@@ -69,6 +69,12 @@ public class EdgeAPI extends GraphAPI {
         return result.readList(this.type(), Edge.class);
     }
 
+    public Edge update(String edgeid, Edge edge) {
+        Map<String, Object> params = ImmutableMap.of("action", "append");
+        RestResult result = this.client.put(this.path(), edgeid, edge, params);
+        return result.readObject(Edge.class);
+    }
+
     public Edge append(Edge edge) {
         String id = edge.id();
         Map<String, Object> params = ImmutableMap.of("action", "append");
