@@ -23,6 +23,7 @@ import java.util.Map;
 
 import org.apache.hugegraph.annotation.UnimplementedFeature;
 import org.apache.hugegraph.api.graph.EdgeAPI;
+import org.apache.hugegraph.api.graph.GraphMetricsAPI;
 import org.apache.hugegraph.api.graph.VertexAPI;
 import org.apache.hugegraph.exception.InvalidOperationException;
 import org.apache.hugegraph.structure.GraphElement;
@@ -39,14 +40,22 @@ import org.apache.hugegraph.util.E;
 
 public class GraphManager {
 
+    private final String graphSpace;
     private final String graph;
     private final VertexAPI vertexAPI;
     private final EdgeAPI edgeAPI;
+    private final GraphMetricsAPI graphMetricsAPI;
 
-    public GraphManager(RestClient client, String graph) {
+    public GraphManager(RestClient client, String graphSpace, String graph) {
+        this.graphSpace = graphSpace;
         this.graph = graph;
-        this.vertexAPI = new VertexAPI(client, graph);
-        this.edgeAPI = new EdgeAPI(client, graph);
+        this.vertexAPI = new VertexAPI(client, graphSpace, graph);
+        this.edgeAPI = new EdgeAPI(client, graphSpace, graph);
+        this.graphMetricsAPI = new GraphMetricsAPI(client, graphSpace, graph);
+    }
+
+    public String graphSpace() {
+        return this.graphSpace;
     }
 
     public String graph() {
@@ -90,6 +99,10 @@ public class GraphManager {
         return vertex;
     }
 
+    public void deleteVertex(Object vertexId) {
+        this.vertexAPI.delete(vertexId);
+    }
+
     public List<Vertex> addVertices(List<Vertex> vertices) {
         List<Object> ids = this.vertexAPI.create(vertices);
         for (int i = 0; i < vertices.size(); i++) {
@@ -201,6 +214,12 @@ public class GraphManager {
         return vertex;
     }
 
+    public Vertex updateVertexProperty(String vertexid, Vertex vertex) {
+        vertex = this.vertexAPI.update(vertexid, vertex);
+        this.attachManager(vertex);
+        return vertex;
+    }
+
     public Vertex eliminateVertexProperty(Vertex vertex) {
         vertex = this.vertexAPI.eliminate(vertex);
         this.attachManager(vertex);
@@ -250,6 +269,10 @@ public class GraphManager {
         return edge;
     }
 
+    public void deleteEdge(String edgeId) {
+        this.edgeAPI.delete(edgeId);
+    }
+
     public List<Edge> addEdges(List<Edge> edges) {
         return this.addEdges(edges, true);
     }
@@ -441,12 +464,46 @@ public class GraphManager {
         return edge;
     }
 
+    public Edge updateEdgeProperty(String edgeid, Edge edge) {
+        edge = this.edgeAPI.update(edgeid, edge);
+        this.attachManager(edge);
+        return edge;
+    }
+
     public Edge eliminateEdgeProperty(Edge edge) {
         edge = this.edgeAPI.eliminate(edge);
         this.attachManager(edge);
         return edge;
     }
 
+    public long createEVCountJob() {
+        return this.graphMetricsAPI.createEVCountJob();
+    }
+
+    public GraphMetricsAPI.ElementCount getEVCount(String strDate) {
+        return this.graphMetricsAPI.getEVCount(strDate);
+    }
+
+    public Map<String, GraphMetricsAPI.ElementCount> getEVCountByMonth(String strMonth) {
+        return this.graphMetricsAPI.getEVCountByMonth(strMonth);
+    }
+
+    public long createTypeCountJob() {
+        return this.graphMetricsAPI.createTypeCountJob();
+    }
+
+    public GraphMetricsAPI.TypeCount getTypeCount(String strDate) {
+        return this.graphMetricsAPI.getTypeCount(strDate);
+    }
+
+    public GraphMetricsAPI.TypeCounts getTypeCounts(String from, String to) {
+        return this.graphMetricsAPI.getTypeCounts(from, to);
+    }
+
+    public Map<String, GraphMetricsAPI.TypeCount> getTypeCountByMonth(String strMonth) {
+        return this.graphMetricsAPI.getTypeCountByMonth(strMonth);
+    }
+
     private Object getValue(String key, Object... keyValues) {
         E.checkArgument((keyValues.length & 0x01) == 0,
                         "The number of parameters must be even");
