@@ -35,10 +35,10 @@ import org.apache.hugegraph.structure.schema.PropertyKey;
  */
 public class HBaseSerializer {
 
-    private int edgeLogicPartitions;
-    private int vertexLogicPartitions;
-    private HugeClient client;
-    private GraphSchema graphSchema;
+    private final int edgeLogicPartitions;
+    private final int vertexLogicPartitions;
+    private final HugeClient client;
+    private final GraphSchema graphSchema;
 
     public HBaseSerializer(HugeClient client, int vertexPartitions, int edgePartitions) {
         this.client = client;
@@ -51,16 +51,17 @@ public class HBaseSerializer {
         byte[] array = null;
         if (e.type() == "vertex" && e.id() != null) {
             BytesBuffer buffer = BytesBuffer.allocate(2 + 1 + e.id().toString().length());
-            buffer.writeShort(getPartition(HugeType.VERTEX,  IdGenerator.of(e.id())));
+            buffer.writeShort(getPartition(HugeType.VERTEX, IdGenerator.of(e.id())));
             buffer.writeId(IdGenerator.of(e.id()));
             array = buffer.bytes();
         } else if (e.type() == "edge") {
             BytesBuffer buffer = BytesBuffer.allocate(BytesBuffer.BUF_EDGE_ID);
-            Edge edge = (Edge)e;
+            Edge edge = (Edge) e;
             buffer.writeShort(getPartition(HugeType.EDGE, IdGenerator.of(edge.sourceId())));
             buffer.writeId(IdGenerator.of(edge.sourceId()));
             buffer.write(HugeType.EDGE_OUT.code());
-            buffer.writeId(IdGenerator.of(graphSchema.getEdgeLabel(e.label()).id())); //出现错误
+            buffer.writeId(
+                    IdGenerator.of(graphSchema.getEdgeLabel(e.label()).id())); // Error occurred
             buffer.writeStringWithEnding("");
             buffer.writeId(IdGenerator.of(edge.targetId()));
             array = buffer.bytes();
@@ -78,17 +79,17 @@ public class HBaseSerializer {
             for (Map.Entry<String, Object> entry : e.properties().entrySet()) {
                 PropertyKey propertyKey = graphSchema.getPropertyKey(entry.getKey());
                 buffer.writeVInt(propertyKey.id().intValue());
-                buffer.writeProperty(propertyKey.dataType(),entry.getValue());
+                buffer.writeProperty(propertyKey.dataType(), entry.getValue());
             }
             array = buffer.bytes();
         } else if (e.type() == "edge") {
-            int propsCount =  e.properties().size();
+            int propsCount = e.properties().size();
             BytesBuffer buffer = BytesBuffer.allocate(4 + 16 * propsCount);
             buffer.writeVInt(propsCount);
             for (Map.Entry<String, Object> entry : e.properties().entrySet()) {
                 PropertyKey propertyKey = graphSchema.getPropertyKey(entry.getKey());
                 buffer.writeVInt(propertyKey.id().intValue());
-                buffer.writeProperty(propertyKey.dataType(),entry.getValue());
+                buffer.writeProperty(propertyKey.dataType(), entry.getValue());
             }
             array = buffer.bytes();
         }
