@@ -23,10 +23,12 @@ public enum EdgeLabelType {
 
     PARENT(1, "PARENT"),
 
-    SUB(2, "SUB");
+    SUB(2, "SUB"),
 
-    private final byte code;
-    private final String name;
+    GENERAL(3, "GENERAL");
+
+    private byte code = 0;
+    private String name = null;
 
     EdgeLabelType(int code, String name) {
         assert code < 256;
@@ -46,6 +48,10 @@ public enum EdgeLabelType {
         return this == NORMAL;
     }
 
+    public boolean general() {
+        return this == GENERAL;
+    }
+
     public byte code() {
         return this.code;
     }
