@@ -81,6 +81,14 @@ public class EdgeLabel extends SchemaLabel {
         return this.edgeLabelType.sub();
     }
 
+    public boolean normal() {
+        return this.edgeLabelType.normal();
+    }
+
+    public boolean general() {
+        return this.edgeLabelType.general();
+    }
+
     public String parentLabel() {
         return this.parentLabel;
     }
@@ -170,6 +178,8 @@ public class EdgeLabel extends SchemaLabel {
 
         Builder withBase(String fatherLabel);
 
+        Builder asGeneral();
+
         /**
          * Set the source label of the edge label
          */
@@ -195,6 +205,8 @@ public class EdgeLabel extends SchemaLabel {
         Builder userdata(String key, Object val);
 
         Builder ifNotExist();
+
+        Builder id(long id);
     }
 
     public static class BuilderImpl implements Builder {
@@ -277,6 +289,12 @@ public class EdgeLabel extends SchemaLabel {
             return this;
         }
 
+        @Override
+        public Builder asGeneral() {
+            this.edgeLabel.edgeLabelType = EdgeLabelType.GENERAL;
+            return this;
+        }
+
         /**
          * Set the source label of the edge label
          */
@@ -365,6 +383,12 @@ public class EdgeLabel extends SchemaLabel {
             return this;
         }
 
+        @Override
+        public Builder id(long id) {
+            this.edgeLabel.id = id;
+            return this;
+        }
+
         private void checkFrequency() {
             E.checkArgument(this.edgeLabel.frequency == Frequency.DEFAULT,
                             "Not allowed to change frequency for edge label '%s'",
