@@ -40,10 +40,10 @@ public class TokenApiTest extends AuthApiTest {
 
     @BeforeClass
     public static void init() {
-        tokenAPI = new TokenAPI(initClient(), GRAPH);
-        logoutAPI = new LogoutAPI(initClient(), GRAPH);
-        loginAPI = new LoginAPI(initClient(), GRAPH);
-        userAPI = new UserAPI(initClient(), GRAPH);
+        tokenAPI = new TokenAPI(initClient());
+        logoutAPI = new LogoutAPI(initClient());
+        loginAPI = new LoginAPI(initClient());
+        userAPI = new UserAPI(initClient(), GRAPHSPACE);
     }
 
     @AfterClass
