@@ -18,6 +18,7 @@
 package org.apache.hugegraph.api.traverser;
 
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 
 import org.apache.hugegraph.api.BaseApiTest;
@@ -27,6 +28,7 @@ import org.apache.hugegraph.structure.graph.Path;
 import org.apache.hugegraph.structure.graph.Vertex;
 import org.apache.hugegraph.structure.traverser.Kout;
 import org.apache.hugegraph.structure.traverser.KoutRequest;
+import org.apache.hugegraph.structure.traverser.Steps;
 import org.apache.hugegraph.testutil.Assert;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -53,8 +55,10 @@ public class KoutApiTest extends TraverserApiTest {
 
         long softwareId = vertexLabelAPI.get("software").id();
 
-        List<Object> vertices = koutAPI.get(markoId, Direction.OUT,
-                                            null, 2, true, -1L, -1L, -1);
+        Map<String, Object> koutRes = koutAPI.get(markoId, Direction.OUT,
+                                                  null, 2, true,
+                                                  -1L, -1L, -1L);
+        List<Object> vertices = (List<Object>) koutRes.get("vertices");
         Assert.assertEquals(1, vertices.size());
         Assert.assertTrue(vertices.contains(softwareId + ":ripple"));
     }
@@ -65,8 +69,9 @@ public class KoutApiTest extends TraverserApiTest {
 
         long softwareId = vertexLabelAPI.get("software").id();
 
-        List<Object> vertices = koutAPI.get(markoId, Direction.OUT, null,
-                                            2, false, -1L, -1L, -1);
+        Map<String, Object> koutRes = koutAPI.get(markoId, Direction.OUT, null,
+                                                  2, false, -1L, -1L, -1L);
+        List<Object> vertices = (List<Object>) koutRes.get("vertices");
         Assert.assertEquals(2, vertices.size());
         Assert.assertTrue(vertices.contains(softwareId + ":lop"));
         Assert.assertTrue(vertices.contains(softwareId + ":ripple"));
@@ -79,8 +84,9 @@ public class KoutApiTest extends TraverserApiTest {
         long personId = vertexLabelAPI.get("person").id();
         long softwareId = vertexLabelAPI.get("software").id();
 
-        List<Object> vertices = koutAPI.get(markoId, Direction.BOTH,
-                                            null, 2, true, -1L, -1L, -1);
+        Map<String, Object> koutRes = koutAPI.get(markoId, Direction.BOTH, null,
+                                                  2, true, -1L, -1L, -1L);
+        List<Object> vertices = (List<Object>) koutRes.get("vertices");
         Assert.assertEquals(2, vertices.size());
         Assert.assertTrue(vertices.contains(personId + ":peter"));
         Assert.assertTrue(vertices.contains(softwareId + ":ripple"));
@@ -93,8 +99,9 @@ public class KoutApiTest extends TraverserApiTest {
         long personId = vertexLabelAPI.get("person").id();
         long softwareId = vertexLabelAPI.get("software").id();
 
-        List<Object> vertices = koutAPI.get(markoId, Direction.BOTH, null,
-                                            2, false, -1L, -1L, -1);
+        Map<String, Object> koutRes = koutAPI.get(markoId, Direction.BOTH, null,
+                                                  2, false, -1L, -1L, -1L);
+        List<Object> vertices = (List<Object>) koutRes.get("vertices");
         Assert.assertEquals(4, vertices.size());
         Assert.assertTrue(vertices.contains(personId + ":josh"));
         Assert.assertTrue(vertices.contains(personId + ":peter"));
@@ -108,7 +115,7 @@ public class KoutApiTest extends TraverserApiTest {
 
         Assert.assertThrows(ServerException.class, () -> {
             koutAPI.get(markoId, Direction.BOTH, null,
-                        2, false, -1L, 1L, 2);
+                        2, false, -1L, 1L, 2L);
         }, e -> {
             String expect = "Capacity can't be less than limit, " +
                             "but got capacity '1' and limit '2'";
@@ -122,7 +129,7 @@ public class KoutApiTest extends TraverserApiTest {
 
         Assert.assertThrows(ServerException.class, () -> {
             koutAPI.get(markoId, Direction.BOTH, null,
-                        2, false, -1L, 1L, -1);
+                        2, false, -1L, 1L, -1L);
         }, e -> {
             String expect = "Capacity can't be less than limit, " +
                             "but got capacity '1' and limit '-1'";
@@ -373,7 +380,8 @@ public class KoutApiTest extends TraverserApiTest {
 
         KoutRequest.Builder builder = KoutRequest.builder();
         builder.source(markoId);
-        builder.steps().direction(Direction.BOTH).addEStep("created");
+        builder.steps().direction(Direction.BOTH)
+               .edgeSteps(new Steps.StepEntity("created"));
         builder.maxDepth(1);
         builder.withVertex(true);
         KoutRequest request = builder.build();
@@ -386,7 +394,8 @@ public class KoutApiTest extends TraverserApiTest {
 
         builder = KoutRequest.builder();
         builder.source(markoId);
-        builder.steps().direction(Direction.BOTH).addEStep("created");
+        builder.steps().direction(Direction.BOTH)
+               .edgeSteps(new Steps.StepEntity("created"));
         builder.maxDepth(2);
         builder.withVertex(true);
         request = builder.build();
@@ -399,7 +408,8 @@ public class KoutApiTest extends TraverserApiTest {
 
         builder = KoutRequest.builder();
         builder.source(markoId);
-        builder.steps().direction(Direction.BOTH).addEStep("knows");
+        builder.steps().direction(Direction.BOTH)
+               .edgeSteps(new Steps.StepEntity("knows"));
         builder.maxDepth(1);
         builder.withVertex(true);
         request = builder.build();
@@ -412,7 +422,8 @@ public class KoutApiTest extends TraverserApiTest {
 
         builder = KoutRequest.builder();
         builder.source(markoId);
-        builder.steps().direction(Direction.BOTH).addEStep("knows");
+        builder.steps().direction(Direction.BOTH)
+               .edgeSteps(new Steps.StepEntity("knows"));
         builder.maxDepth(2);
         builder.withVertex(true);
         request = builder.build();
@@ -434,8 +445,8 @@ public class KoutApiTest extends TraverserApiTest {
         KoutRequest.Builder builder = KoutRequest.builder();
         builder.source(markoId);
         builder.steps().direction(Direction.BOTH)
-               .addEStep("knows")
-               .addEStep("created");
+               .edgeSteps(new Steps.StepEntity("knows"))
+               .edgeSteps(new Steps.StepEntity("created"));
         builder.maxDepth(1);
         builder.withVertex(true);
         KoutRequest request = builder.build();
@@ -449,8 +460,8 @@ public class KoutApiTest extends TraverserApiTest {
         builder = KoutRequest.builder();
         builder.source(markoId);
         builder.steps().direction(Direction.BOTH)
-               .addEStep("knows")
-               .addEStep("created");
+               .edgeSteps(new Steps.StepEntity("knows"))
+               .edgeSteps(new Steps.StepEntity("created"));
         builder.maxDepth(2);
         builder.withVertex(true);
         request = builder.build();
@@ -509,7 +520,9 @@ public class KoutApiTest extends TraverserApiTest {
         builder.source(markoId);
         builder.steps()
                .direction(Direction.BOTH)
-               .addEStep("created", ImmutableMap.of("date", "P.gt(\"2014-01-01 00:00:00\")"));
+               .edgeSteps(new Steps.StepEntity("created", ImmutableMap.of("date", "P.gt(\"2014-01" +
+                                                                                  "-01 00:00:00" +
+                                                                                  "\")")));
         builder.maxDepth(1);
         builder.withVertex(true);
         KoutRequest request = builder.build();
@@ -524,7 +537,9 @@ public class KoutApiTest extends TraverserApiTest {
         builder.source(markoId);
         builder.steps()
                .direction(Direction.BOTH)
-               .addEStep("created", ImmutableMap.of("date", "P.gt(\"2014-01-01 00:00:00\")"));
+               .edgeSteps(new Steps.StepEntity("created", ImmutableMap.of("date", "P.gt(\"2014-01" +
+                                                                                  "-01 00:00:00" +
+                                                                                  "\")")));
 
         builder.maxDepth(2);
         builder.withVertex(true);
@@ -540,7 +555,9 @@ public class KoutApiTest extends TraverserApiTest {
         builder.source(markoId);
         builder.steps()
                .direction(Direction.BOTH)
-               .addEStep("created", ImmutableMap.of("date", "P.gt(\"2014-01-01 00:00:00\")"));
+               .edgeSteps(new Steps.StepEntity("created", ImmutableMap.of("date", "P.gt(\"2014-01" +
+                                                                                  "-01 00:00:00" +
+                                                                                  "\")")));
         builder.maxDepth(3);
         builder.withVertex(true);
         request = builder.build();
