@@ -25,20 +25,20 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import org.apache.commons.lang3.StringUtils;
+import org.apache.hugegraph.util.E;
+
 import org.apache.hugegraph.loader.executor.LoadContext;
 import org.apache.hugegraph.loader.mapping.EdgeMapping;
 import org.apache.hugegraph.loader.mapping.InputStruct;
+import org.apache.hugegraph.structure.constant.IdStrategy;
 import org.apache.hugegraph.structure.graph.Edge;
 import org.apache.hugegraph.structure.graph.Vertex;
 import org.apache.hugegraph.structure.schema.EdgeLabel;
 import org.apache.hugegraph.structure.schema.SchemaLabel;
 import org.apache.hugegraph.structure.schema.VertexLabel;
-import org.apache.hugegraph.util.E;
-
 import com.google.common.collect.ImmutableList;
 
-import org.apache.spark.sql.Row;
-
 public class EdgeBuilder extends ElementBuilder<Edge> {
 
     private final EdgeMapping mapping;
@@ -55,13 +55,20 @@ public class EdgeBuilder extends ElementBuilder<Edge> {
         super(context, struct);
         this.mapping = mapping;
         this.edgeLabel = this.getEdgeLabel(this.mapping.label());
-        this.sourceLabel = this.getVertexLabel(this.edgeLabel.sourceLabel());
-        this.targetLabel = this.getVertexLabel(this.edgeLabel.targetLabel());
         this.nonNullKeys = this.nonNullableKeys(this.edgeLabel);
-        // Ensure that the source/target id fields are matched with id strategy
+        if (this.edgeLabel.edgeLabelType().general()) {
+            // the IdStrategy of both ends is uniformly set to CUSTOMIZE_STRING
+            this.sourceLabel = new VertexLabel("~general");
+            this.targetLabel = new VertexLabel("~general");
+            this.sourceLabel.idStrategy(IdStrategy.CUSTOMIZE_STRING);
+            this.targetLabel.idStrategy(IdStrategy.CUSTOMIZE_STRING);
+        } else {
+            this.sourceLabel = this.getVertexLabel(this.edgeLabel.sourceLabel());
+            this.targetLabel = this.getVertexLabel(this.edgeLabel.targetLabel());
+        }
+        // Ensure that the source/target id fileds are matched with id strategy
         this.checkIdFields(this.sourceLabel, this.mapping.sourceFields());
         this.checkIdFields(this.targetLabel, this.mapping.targetFields());
-
         this.vertexIdsIndex = null;
     }
 
@@ -111,62 +118,19 @@ public class EdgeBuilder extends ElementBuilder<Edge> {
         return edges;
     }
 
-    @Override
-    public List<Edge> build(Row row) {
-        String[] names = row.schema().fieldNames();
-        Object[] values = new Object[row.size()];
-        for (int i = 0; i < row.size(); i++) {
-            values[i] = row.get(i);
-        }
-        if (this.vertexIdsIndex == null ||
-            !Arrays.equals(this.lastNames, names)) {
-            this.vertexIdsIndex = this.extractVertexIdsIndex(names);
-        }
-
-        this.lastNames = names;
-        EdgeKVPairs kvPairs = this.newEdgeKVPairs();
-        kvPairs.source.extractFromEdge(names, values, this.vertexIdsIndex.sourceIndexes);
-        kvPairs.target.extractFromEdge(names, values, this.vertexIdsIndex.targetIndexes);
-        kvPairs.extractProperties(names, values);
-
-        List<Vertex> sources = kvPairs.source.buildVertices(false);
-        List<Vertex> targets = kvPairs.target.buildVertices(false);
-        if (sources.isEmpty() || targets.isEmpty()) {
-            return ImmutableList.of();
-        }
-        E.checkArgument(sources.size() == 1 || targets.size() == 1 ||
-                        sources.size() == targets.size(),
-                        "The elements number of source and target must be: " +
-                        "1 to n, n to 1, n to n");
-        int size = Math.max(sources.size(), targets.size());
-        List<Edge> edges = new ArrayList<>(size);
-        for (int i = 0; i < size; i++) {
-            Vertex source = i < sources.size() ?
-                            sources.get(i) : sources.get(0);
-            Vertex target = i < targets.size() ?
-                            targets.get(i) : targets.get(0);
-            Edge edge = new Edge(this.mapping.label());
-            edge.source(source);
-            edge.target(target);
-            // Add properties
-            this.addProperties(edge, kvPairs.properties);
-            this.checkNonNullableKeys(edge);
-            edges.add(edge);
-        }
-        return edges;
-    }
-
     private EdgeKVPairs newEdgeKVPairs() {
         EdgeKVPairs kvPairs = new EdgeKVPairs();
         kvPairs.source = this.newKVPairs(this.sourceLabel,
                                          this.mapping.unfoldSource());
+        kvPairs.source.headerCaseSensitive(this.headerCaseSensitive());
         kvPairs.target = this.newKVPairs(this.targetLabel,
                                          this.mapping.unfoldTarget());
+        kvPairs.target.headerCaseSensitive(this.headerCaseSensitive());
         return kvPairs;
     }
 
     @Override
-    public SchemaLabel schemaLabel() {
+    protected SchemaLabel schemaLabel() {
         return this.edgeLabel;
     }
 
@@ -189,10 +153,10 @@ public class EdgeBuilder extends ElementBuilder<Edge> {
         } else if (vertexLabel.idStrategy().isPrimaryKey()) {
             E.checkArgument(fields.size() >= 1,
                             "The source/target field must contains some " +
-                            "columns when id strategy is PrimaryKey");
+                            "columns when id strategy is CUSTOMIZE");
         } else {
-            throw new IllegalArgumentException("Unsupported AUTOMATIC id strategy " +
-                                               "for hugegraph-loader");
+            throw new IllegalArgumentException(
+                    "Unsupported AUTOMATIC id strategy for hugegraph-loader");
         }
     }
 
@@ -215,7 +179,7 @@ public class EdgeBuilder extends ElementBuilder<Edge> {
                     continue;
                 }
 
-                String key = mapping.mappingField(fieldName);
+                String key = mappingField(fieldName);
                 if (isIdField(fieldName) &&
                     !props.contains(fieldName) && !props.contains(key)) {
                     continue;
@@ -230,25 +194,27 @@ public class EdgeBuilder extends ElementBuilder<Edge> {
     private VertexIdsIndex extractVertexIdsIndex(String[] names) {
         VertexIdsIndex index = new VertexIdsIndex();
         index.sourceIndexes = new int[this.mapping.sourceFields().size()];
-        int idx = 0;
-        for (String field : this.mapping.sourceFields()) {
-            for (int pos = 0; pos < names.length; pos++) {
-                String name = names[pos];
-                if (field.equals(name)) {
-                    index.sourceIndexes[idx++] = pos;
-                }
-            }
+        //
+        List<String> listNames = Arrays.asList(names);
+        for (int idx = 0; idx < this.mapping.sourceFields().size(); idx++) {
+            String field = this.mapping.sourceFields().get(idx);
+            int i = listNames.indexOf(field);
+            E.checkArgument(i >= 0,
+                            "mapping file error: edges.source(%s)" +
+                            " not in file header([%s])", field,
+                            StringUtils.joinWith(",", names));
+            index.sourceIndexes[idx] = i;
         }
 
         index.targetIndexes = new int[this.mapping.targetFields().size()];
-        idx = 0;
-        for (String field : this.mapping.targetFields()) {
-            for (int pos = 0; pos < names.length; pos++) {
-                String name = names[pos];
-                if (field.equals(name)) {
-                    index.targetIndexes[idx++] = pos;
-                }
-            }
+        for (int idx = 0; idx < this.mapping.targetFields().size(); idx++) {
+            String field = this.mapping.targetFields().get(idx);
+            int i = listNames.indexOf(field);
+            E.checkArgument(i >= 0,
+                            "mapping file error: edges.target(%s)" +
+                            " not in file header([%s])", field,
+                            StringUtils.joinWith(",", names));
+            index.targetIndexes[idx] = i;
         }
         return index;
     }
