@@ -21,6 +21,7 @@ import java.nio.ByteBuffer;
 import java.nio.CharBuffer;
 import java.nio.charset.CharsetEncoder;
 import java.nio.charset.CoderResult;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -35,27 +36,29 @@ import java.util.stream.Collectors;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.ListUtils;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.hugegraph.util.E;
+import org.apache.hugegraph.util.LongEncoding;
 
 import org.apache.hugegraph.loader.constant.Constants;
 import org.apache.hugegraph.loader.executor.LoadContext;
+import org.apache.hugegraph.loader.filter.util.ShortIdConfig;
 import org.apache.hugegraph.loader.mapping.ElementMapping;
 import org.apache.hugegraph.loader.mapping.InputStruct;
-import org.apache.hugegraph.loader.util.DataTypeUtil;
 import org.apache.hugegraph.loader.source.InputSource;
+import org.apache.hugegraph.loader.util.DataTypeUtil;
 import org.apache.hugegraph.structure.GraphElement;
+import org.apache.hugegraph.structure.constant.DataType;
 import org.apache.hugegraph.structure.constant.IdStrategy;
 import org.apache.hugegraph.structure.graph.Vertex;
 import org.apache.hugegraph.structure.schema.EdgeLabel;
 import org.apache.hugegraph.structure.schema.PropertyKey;
 import org.apache.hugegraph.structure.schema.SchemaLabel;
 import org.apache.hugegraph.structure.schema.VertexLabel;
-import org.apache.hugegraph.util.E;
-import org.apache.hugegraph.util.LongEncoding;
+
+import java.util.HashSet;
 
 import com.google.common.collect.ImmutableList;
 
-import org.apache.spark.sql.Row;
-
 public abstract class ElementBuilder<GE extends GraphElement> {
 
     private final InputStruct struct;
@@ -64,26 +67,51 @@ public abstract class ElementBuilder<GE extends GraphElement> {
     // NOTE: CharsetEncoder is not thread safe
     private final CharsetEncoder encoder;
     private final ByteBuffer buffer;
+    private LoadContext context;
+    private boolean usePrefilter;
+    private static HashSet<byte[]> bytesSet;
+    private static HashSet<Long> longSet;
 
     public ElementBuilder(LoadContext context, InputStruct struct) {
         this.struct = struct;
         this.schema = context.schemaCache();
         this.encoder = Constants.CHARSET.newEncoder();
         this.buffer = ByteBuffer.allocate(Constants.VERTEX_ID_LIMIT);
+        this.context = context;
+        this.usePrefilter = this.context.options().usePrefilter;
+        if (longSet == null) {
+            synchronized (ElementBuilder.class) {
+                if (longSet == null) {
+                    longSet = new HashSet<>();
+                    bytesSet = new HashSet<>();
+                }
+            }
+        }
     }
 
     public abstract ElementMapping mapping();
 
     public abstract List<GE> build(String[] names, Object[] values);
 
-    public abstract List<GE> build(Row row);
-
-    public abstract SchemaLabel schemaLabel();
+    protected abstract SchemaLabel schemaLabel();
 
     protected abstract Collection<String> nonNullableKeys();
 
     protected abstract boolean isIdField(String fieldName);
 
+    // Whether builder distinguishes header case sensitivity
+    protected boolean headerCaseSensitive() {
+        return this.struct.input().headerCaseSensitive();
+    }
+
+    protected boolean headerEqual(String header1, String header2) {
+        if (this.headerCaseSensitive()) {
+            return header1.equals(header2);
+        } else {
+            return header1.equalsIgnoreCase(header2);
+        }
+    }
+
     @SuppressWarnings("unchecked")
     protected Collection<String> nonNullableKeys(SchemaLabel schemaLabel) {
         return CollectionUtils.subtract(schemaLabel.properties(),
@@ -109,6 +137,52 @@ public abstract class ElementBuilder<GE extends GraphElement> {
         }
     }
 
+    protected boolean isSelectedField(String fieldName) {
+        ElementMapping mapping = this.mapping();
+        Set<String> selectedFields = mapping.selectedFields();
+
+        if (selectedFields.isEmpty()) {
+            return true;
+        }
+
+        if (this.headerCaseSensitive()) {
+            if (selectedFields.contains(fieldName)) {
+                return true;
+            }
+        } else {
+            for (String selectedField : selectedFields) {
+                if (headerEqual(selectedField, fieldName)) {
+                    return true;
+                }
+            }
+        }
+
+        return false;
+    }
+
+    protected boolean isIgnoredField(String fieldName) {
+        ElementMapping mapping = this.mapping();
+        Set<String> ignoredFields = mapping.ignoredFields();
+
+        if (ignoredFields.isEmpty()) {
+            return false;
+        }
+
+        if (this.headerCaseSensitive()) {
+            if (ignoredFields.contains(fieldName)) {
+                return true;
+            }
+        } else {
+            for (String ignoredField : ignoredFields) {
+                if (headerEqual(ignoredField, fieldName)) {
+                    return true;
+                }
+            }
+        }
+
+        return false;
+    }
+
     /**
      * Retain only the key-value pairs needed by the current vertex or edge
      */
@@ -117,18 +191,26 @@ public abstract class ElementBuilder<GE extends GraphElement> {
         Set<String> selectedFields = mapping.selectedFields();
         Set<String> ignoredFields = mapping.ignoredFields();
         // Retain selected fields or remove ignored fields
-        if (!selectedFields.isEmpty() && !selectedFields.contains(fieldName)) {
+        if (!isSelectedField(fieldName)) {
             return false;
         }
-        if (!ignoredFields.isEmpty() && ignoredFields.contains(fieldName)) {
+        if (isIgnoredField(fieldName)) {
             return false;
         }
-        String mappedKey = mapping.mappingField(fieldName);
+
+        String mappedKey = mappingField(fieldName);
+
         Set<String> nullableKeys = this.schemaLabel().nullableKeys();
         Set<Object> nullValues = mapping.nullValues();
         if (nullableKeys.isEmpty() || nullValues.isEmpty()) {
             return true;
         }
+
+        // When fieldValue is empty and schema allows null
+        if (fieldValue == null && nullableKeys.contains(mappedKey)) {
+            return false;
+        }
+
         return !nullableKeys.contains(mappedKey) ||
                !nullValues.contains(fieldValue);
     }
@@ -166,7 +248,7 @@ public abstract class ElementBuilder<GE extends GraphElement> {
             Collection<String> missed = CollectionUtils.subtract(requiredKeys,
                                                                  keys);
             E.checkArgument(false, "All non-null property keys %s of '%s' " +
-                            "must be set, but missed keys %s",
+                                   "must be set, but missed keys %s",
                             requiredKeys, this.schemaLabel().name(), missed);
         }
     }
@@ -188,16 +270,40 @@ public abstract class ElementBuilder<GE extends GraphElement> {
             return fieldValue;
         }
         String fieldStrValue = String.valueOf(fieldValue);
-        return this.mapping().mappingValue(fieldName, fieldStrValue);
+        return this.mapping().mappingValue(fieldName, fieldStrValue,
+                                           this.headerCaseSensitive());
+    }
+
+    protected String mappingField(String fileName) {
+        return this.mapping().mappingField(fileName,
+                                           this.headerCaseSensitive());
     }
 
     private void customizeId(VertexLabel vertexLabel, Vertex vertex,
                              String idField, Object idValue) {
+        ShortIdConfig shortIdConfig = this.context.options().getShortIdConfig(vertexLabel.name());
+        if (idField == null && shortIdConfig != null &&
+            shortIdConfig.getPrimaryKeyField() != null) {
+            return;
+        }
         E.checkArgumentNotNull(idField, "The vertex id field can't be null");
-        E.checkArgumentNotNull(idValue, "The vertex id value can't be null");
+        E.checkArgumentNotNull(idValue, "The vertex id value of field(%s)" +
+                                        " can't be null", idField);
         IdStrategy idStrategy = vertexLabel.idStrategy();
+        if (shortIdConfig != null) {
+            DataType type =
+                    this.context.options().getShortIdConfig(vertexLabel.name()).getIdFieldType();
+            if (type.isText()) {
+                idStrategy = IdStrategy.CUSTOMIZE_STRING;
+            } else if (type.isUUID()) {
+                idStrategy = IdStrategy.CUSTOMIZE_UUID;
+            } else if (type.isNumber()) {
+                idStrategy = IdStrategy.CUSTOMIZE_NUMBER;
+            }
+        }
+
         if (idStrategy.isCustomizeString()) {
-            String id = (String) idValue;
+            String id = (String) idValue.toString();
             this.checkVertexIdLength(id);
             vertex.id(id);
         } else if (idStrategy.isCustomizeNumber()) {
@@ -222,10 +328,11 @@ public abstract class ElementBuilder<GE extends GraphElement> {
             return;
         }
         // NOTE: The nullable values has been filtered before this
-        E.checkArgument(fieldValue != null, "The field value can't be null");
+        E.checkArgument(fieldValue != null, "The field(%s) value can't be " +
+                                            "null", fieldName);
         E.checkArgument(DataTypeUtil.isSimpleValue(fieldValue),
-                        "The field value must be simple type, actual is '%s'",
-                        fieldValue.getClass());
+                        "The field(%s) value must be simple type, actual is " +
+                        "'%s'", fieldName, fieldValue.getClass());
     }
 
     private boolean vertexIdEmpty(VertexLabel vertexLabel, Vertex vertex) {
@@ -258,7 +365,8 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                                   Object... primaryValues) {
         StringBuilder vertexId = new StringBuilder();
         StringBuilder vertexKeysId = new StringBuilder();
-        for (Object value : primaryValues) {
+        for (int i = 0; i < primaryValues.length; i++) {
+            Object value = primaryValues[i];
             String pkValue;
             if (value instanceof Number || value instanceof Date) {
                 pkValue = LongEncoding.encodeNumber(value);
@@ -305,9 +413,17 @@ public abstract class ElementBuilder<GE extends GraphElement> {
         // General properties
         public Map<String, Object> properties;
 
+        public boolean headerCaseSensitive;
+
+        public void headerCaseSensitive(boolean f) {
+            this.headerCaseSensitive = f;
+        }
+
         public VertexKVPairs(VertexLabel vertexLabel) {
             this.vertexLabel = vertexLabel;
             this.properties = null;
+
+            this.headerCaseSensitive = true;
         }
 
         public abstract void extractFromVertex(String[] names,
@@ -321,6 +437,29 @@ public abstract class ElementBuilder<GE extends GraphElement> {
         public List<Object> splitField(String key, Object value) {
             return DataTypeUtil.splitField(key, value, struct.input());
         }
+
+        public boolean verifyVertex(VertexLabel vertexLabel, Object id) {
+            if (usePrefilter) {
+                if (vertexLabel.idStrategy().isCustomizeNumber()) {
+                    Long longId = (Long) id;
+                    boolean contains = longSet.contains(longId);
+                    if (!contains) {
+                        longSet.add(longId);
+                    }
+                    return contains;
+                } else {
+                    byte[] bytes =
+                            id.toString().getBytes(StandardCharsets.UTF_8);
+                    boolean contains = bytesSet.contains(
+                            bytes);
+                    if (!contains) {
+                        bytesSet.add(bytes);
+                    }
+                    return contains;
+                }
+            }
+            return false;
+        }
     }
 
     public class VertexIdKVPairs extends VertexKVPairs {
@@ -348,7 +487,7 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                     this.idField = fieldName;
                     this.idValue = mappingValue(fieldName, fieldValue);
                 } else {
-                    String key = mapping().mappingField(fieldName);
+                    String key = mappingField(fieldName);
                     Object value = mappingValue(fieldName, fieldValue);
                     this.properties.put(key, value);
                 }
@@ -372,8 +511,11 @@ public abstract class ElementBuilder<GE extends GraphElement> {
             if (vertexIdEmpty(vertexLabel, vertex)) {
                 return ImmutableList.of();
             }
+            if (withProperty && verifyVertex(vertexLabel, vertex.id())) {
+                return ImmutableList.of();
+            }
             if (withProperty) {
-                String key = mapping().mappingField(this.idField);
+                String key = mappingField(this.idField);
                 // The id field is also used as a general property
                 if (vertexLabel.properties().contains(key)) {
                     addProperty(vertex, key, this.idValue);
@@ -390,7 +532,7 @@ public abstract class ElementBuilder<GE extends GraphElement> {
         // The idField(raw field), like: id
         private String idField;
         /*
-         * The multiple idValues(split and mapped)
+         * The multiple idValues(spilted and mapped)
          * like: A|B|C -> [1,2,3]
          */
         private List<Object> idValues;
@@ -417,7 +559,7 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                         return mappingValue(fieldName, rawIdValue);
                     }).collect(Collectors.toList());
                 } else {
-                    String key = mapping().mappingField(fieldName);
+                    String key = mappingField(fieldName);
                     Object value = mappingValue(fieldName, fieldValue);
                     this.properties.put(key, value);
                 }
@@ -439,6 +581,8 @@ public abstract class ElementBuilder<GE extends GraphElement> {
 
         @Override
         public List<Vertex> buildVertices(boolean withProperty) {
+            E.checkArgument(this.idValues != null,
+                            "The flat id values shouldn't be null");
             List<Vertex> vertices = new ArrayList<>(this.idValues.size());
             for (Object idValue : this.idValues) {
                 Vertex vertex = new Vertex(vertexLabel.name());
@@ -446,8 +590,11 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                 if (vertexIdEmpty(vertexLabel, vertex)) {
                     continue;
                 }
+                if (withProperty && verifyVertex(vertexLabel, vertex.id())) {
+                    continue;
+                }
                 if (withProperty) {
-                    String key = mapping().mappingField(this.idField);
+                    String key = mappingField(this.idField);
                     // The id field is also used as a general property
                     if (vertexLabel.properties().contains(key)) {
                         addProperty(vertex, key, idValue);
@@ -481,6 +628,10 @@ public abstract class ElementBuilder<GE extends GraphElement> {
         @Override
         public void extractFromVertex(String[] names, Object[] values) {
             List<String> primaryKeys = this.vertexLabel.primaryKeys();
+            List<String> lowerCasePrimaryKeys
+                    = primaryKeys.stream().map(k -> k.toLowerCase())
+                                 .collect(Collectors.toList());
+
             this.pkNames = primaryKeys;
             this.pkValues = new Object[primaryKeys.size()];
             // General properties
@@ -491,15 +642,29 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                 if (!retainField(fieldName, fieldValue)) {
                     continue;
                 }
-                String key = mapping().mappingField(fieldName);
-                if (primaryKeys.contains(key)) {
-                    // Don't put primary key/values into general properties
-                    int index = primaryKeys.indexOf(key);
-                    Object pkValue = mappingValue(fieldName, fieldValue);
-                    this.pkValues[index] = pkValue;
+                String key = mappingField(fieldName);
+
+                if (this.headerCaseSensitive) {
+                    if (primaryKeys.contains(key)) {
+                        // Don't put primary key/values into general properties
+                        int index = primaryKeys.indexOf(key);
+                        Object pkValue = mappingValue(fieldName, fieldValue);
+                        this.pkValues[index] = pkValue;
+                    } else {
+                        Object value = mappingValue(fieldName, fieldValue);
+                        this.properties.put(key, value);
+                    }
                 } else {
-                    Object value = mappingValue(fieldName, fieldValue);
-                    this.properties.put(key, value);
+                    String lowerCaseKey = key.toLowerCase();
+                    if (lowerCasePrimaryKeys.contains(lowerCaseKey)) {
+                        // Don't put primary key/values into general properties
+                        int index = lowerCasePrimaryKeys.indexOf(lowerCaseKey);
+                        Object pkValue = mappingValue(fieldName, fieldValue);
+                        this.pkValues[index] = pkValue;
+                    } else {
+                        Object value = mappingValue(fieldName, fieldValue);
+                        this.properties.put(key, value);
+                    }
                 }
             }
         }
@@ -510,7 +675,7 @@ public abstract class ElementBuilder<GE extends GraphElement> {
             this.pkNames = new ArrayList<>(fieldIndexes.length);
             for (int fieldIndex : fieldIndexes) {
                 String fieldName = names[fieldIndex];
-                String mappingField = mapping().mappingField(fieldName);
+                String mappingField = mappingField(fieldName);
                 this.pkNames.add(mappingField);
             }
             List<String> primaryKeys = this.vertexLabel.primaryKeys();
@@ -551,12 +716,92 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                 }
                 addProperties(vertex, this.properties);
                 checkNonNullableKeys(vertex);
+            } else {
+                vertex.id(id);
+            }
+            if (withProperty && verifyVertex(vertexLabel, vertex.id())) {
+                return ImmutableList.of();
             }
-            vertex.id(id);
             return ImmutableList.of(vertex);
         }
     }
 
+    /**
+     * Vertex OLAP Property Parse
+     */
+    public class VertexOlapKVPairs extends VertexKVPairs {
+
+        // The idField(raw field), like: id
+        private String idField;
+        /*
+         * The field value
+         */
+        private Object fieldValue;
+
+        public VertexOlapKVPairs(VertexLabel vertexLabel) {
+            super(vertexLabel);
+        }
+
+        @Override
+        public void extractFromVertex(String[] names, Object[] values) {
+            // General OLAP properties
+            this.properties = new HashMap<>();
+            for (int i = 0; i < names.length; i++) {
+                String fieldName = names[i];
+                Object fieldValue = values[i];
+                if (!retainField(fieldName, fieldValue)) {
+                    continue;
+                }
+                if (isIdField(fieldName)) {
+                    this.idField = fieldName;
+                    this.fieldValue = fieldValue;
+                } else {
+                    String key = mappingField(fieldName);
+                    Object value = mappingValue(fieldName, fieldValue);
+                    this.properties.put(key, value);
+                }
+            }
+        }
+
+        @Override
+        public void extractFromEdge(String[] names, Object[] values,
+                                    int[] fieldIndexes) {
+            // pass OLAP properties for vertices
+        }
+
+        @Override
+        public List<Vertex> buildVertices(boolean withProperty) {
+            Vertex vertex = new Vertex(null);
+            olapVertexId(vertexLabel, vertex, this.idField, fieldValue);
+            if (withProperty) {
+                String key = mappingField(this.idField);
+                // The id field is also used as a general property
+                if (vertexLabel.properties().contains(key)) {
+                    addProperty(vertex, key, fieldValue);
+                }
+                addProperties(vertex, this.properties);
+            }
+            return ImmutableList.of(vertex);
+        }
+    }
+
+    public void olapVertexId(VertexLabel vertexLabel, Vertex vertex,
+                             String idField, Object idValue) {
+        IdStrategy idStrategy = vertexLabel.idStrategy();
+        if (idStrategy.isCustomizeString() || idStrategy.isPrimaryKey()) {
+            String id = (String) idValue.toString();
+            this.checkVertexIdLength(id);
+            vertex.id(id);
+        } else if (idStrategy.isCustomizeNumber() || idStrategy.isAutomatic()) {
+            Long id = DataTypeUtil.parseNumber(idField, idValue);
+            vertex.id(id);
+        } else {
+            assert idStrategy.isCustomizeUuid();
+            UUID id = DataTypeUtil.parseUUID(idField, idValue);
+            vertex.id(id);
+        }
+    }
+
     public class VertexFlatPkKVPairs extends VertexKVPairs {
 
         /*
@@ -590,7 +835,7 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                 if (!retainField(fieldName, fieldValue)) {
                     continue;
                 }
-                String key = mapping().mappingField(fieldName);
+                String key = mappingField(fieldName);
                 if (!handledPk && primaryKeys.contains(key)) {
                     // Don't put primary key/values into general properties
                     List<Object> rawPkValues = splitField(fieldName,
@@ -614,10 +859,10 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                             "In case unfold is true, just supported " +
                             "a single primary key");
             String fieldName = names[fieldIndexes[0]];
-            this.pkName = mapping().mappingField(fieldName);
+            this.pkName = mappingField(fieldName);
             String primaryKey = primaryKeys.get(0);
             E.checkArgument(this.pkName.equals(primaryKey),
-                            "Make sure the primary key field '%s' is " +
+                            "Make sure the the primary key field '%s' is " +
                             "not empty, or check whether the headers or " +
                             "field_mapping are configured correctly",
                             primaryKey);
@@ -647,8 +892,12 @@ public abstract class ElementBuilder<GE extends GraphElement> {
                     addProperty(vertex, this.pkName, pkValue, false);
                     addProperties(vertex, this.properties);
                     checkNonNullableKeys(vertex);
+                } else {
+                    vertex.id(id);
+                }
+                if (withProperty && verifyVertex(vertexLabel, vertex.id())) {
+                    continue;
                 }
-                vertex.id(id);
                 vertices.add(vertex);
             }
             return vertices;
