@@ -137,9 +137,10 @@ public class HugeGraphOutputFormat<T> extends RichOutputFormat<T> {
             // Add batch
             List<String> graphElements = builder.getValue();
             graphElements.add(row.toString());
-            if (graphElements.size() >= elementMapping.batchSize()) {
-                flush(builder.getKey(), builder.getValue());
-            }
+            //if (graphElements.size() >= elementMapping.batchSize()) {
+            //    flush(builder.getKey(), builder.getValue());
+            //}
+            flush(builder.getKey(), builder.getValue());
         }
     }
 
