@@ -18,9 +18,9 @@
 package org.apache.hugegraph.loader.reader.file;
 
 import java.io.File;
+import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -30,10 +30,12 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hugegraph.loader.exception.LoadException;
 import org.apache.hugegraph.loader.progress.FileItemProgress;
 import org.apache.hugegraph.loader.progress.InputItemProgress;
+import org.apache.hugegraph.loader.reader.Readable;
+import org.apache.hugegraph.loader.source.InputSource;
 import org.apache.hugegraph.loader.source.file.Compression;
 import org.apache.hugegraph.loader.source.file.FileFilter;
 import org.apache.hugegraph.loader.source.file.FileSource;
-import org.apache.hugegraph.loader.reader.Readable;
+import com.google.common.collect.ImmutableSet;
 
 public class LocalFileReader extends FileReader {
 
@@ -41,6 +43,13 @@ public class LocalFileReader extends FileReader {
         super(source);
     }
 
+    @Override
+    public FileReader newFileReader(InputSource source, Readable readable) {
+        LocalFileReader reader = new LocalFileReader((FileSource) source);
+        reader.readables(ImmutableSet.of(readable).iterator());
+        return reader;
+    }
+
     @Override
     protected List<Readable> scanReadables() {
         File file = FileUtils.getFile(this.source().path());
@@ -92,6 +101,10 @@ public class LocalFileReader extends FileReader {
         }
     }
 
+    public boolean multiReaders() {
+        return true;
+    }
+
     private static class LocalFile implements Readable {
 
         private final File file;
@@ -116,7 +129,7 @@ public class LocalFileReader extends FileReader {
 
         @Override
         public InputStream open() throws IOException {
-            return Files.newInputStream(this.file.toPath());
+            return new FileInputStream(this.file);
         }
 
         @Override
